mautrix-appservice-python
=========================

|PyPI badge| |Python versions| |License|

A Python 3 asyncio-based Matrix application service framework.

.. |PyPI badge| image:: https://img.shields.io/pypi/v/mautrix-appservice.svg
   :target: https://pypi.python.org/pypi/mautrix-appservice
.. |Python versions| image:: https://img.shields.io/pypi/pyversions/mautrix-appservice.svg
.. |License| image:: https://img.shields.io/github/license/tulir/mautrix-appservice.svg
   :target: https://github.com/tulir/mautrix-appservice-python/blob/master/LICENSE
